## Typing stubs for icalendar

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`icalendar`](https://github.com/collective/icalendar) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `icalendar`. This version of
`types-icalendar` aims to provide accurate annotations for
`icalendar~=6.1.2`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/icalendar`](https://github.com/python/typeshed/tree/main/stubs/icalendar)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.397,
and pytype 2024.10.11.
It was generated from typeshed commit
[`b4e49dd52102348e1bdbd6a83cc1817ec4f8a854`](https://github.com/python/typeshed/commit/b4e49dd52102348e1bdbd6a83cc1817ec4f8a854).